@@ -67,6 +67,21 @@ class DataLoader:
             return n // self.batch_size
         return (n + self.batch_size - 1) // self.batch_size
 
+    def __getitem__(self, idx):
+        """Get a specific batch by index. Enables random.choice(dataloader)."""
+        if idx < 0 or idx >= len(self):
+            raise IndexError(f"Batch index {idx} out of range [0, {len(self)})")
+        # Get all batch indices for consistent ordering
+        batches = list(self._batch_indices())
+        batch_idxs = batches[idx]
+        # Load the batch synchronously
+        batch_data = [self.dataset[i] for i in batch_idxs]
+        Xs, ys = zip(*batch_data)
+        # Stack into tensors
+        X = Tensor(xp.stack([x.data for x in Xs], axis=0), dtype=Xs[0].dtype)
+        y = Tensor(xp.stack([y.data for y in ys], axis=0), dtype=ys[0].dtype)
+        return X, y
+
     # --- helpers -------------------------------------------------------------
 
     def _ensure_executor(self):
